@@ -45,26 +45,27 @@ class BasesInvalidOperationError(BasesError):  # pragma: no cover
 
     def __str__(self):
         if self._other is None:
-            return f"invalid operation for Radix: {self._operator}"
-        return f"invalid operation {self._operator} for Radix and {type(self._other).__name__}"
+            return "invalid operation for Radix: %s" % self._operator
+        return "invalid operation %s for Radix and %s" % (
+            self._operator,
+            type(self._other).__name__,
+        )
 
 
 class BasesValueError(BasesError):
-    """
-    Raised when a parameter has an unacceptable value.
+    """ Raised when a parameter has an unacceptable value.
 
-    May also be raised when the parameter has an unacceptable type.
+        May also be raised when the parameter has an unacceptable type.
     """
 
     _FMT_STR = "value '%s' for parameter %s is unacceptable"
 
     def __init__(self, value, param, msg=None):
-        """
-        Initializer.
+        """ Initializer.
 
-        :param object value: the value
-        :param str param: the parameter
-        :param str msg: an explanatory message
+            :param object value: the value
+            :param str param: the parameter
+            :param str msg: an explanatory message
         """
         # pylint: disable=super-init-not-called
         self._value = value
